
function ssw_flare_locator, index, data, oindex,odata , $
   limb_pad=limb_pad, smooth_width=smooth_width, nosmooth=nosmooth , $
   dark_flare=dark_flare, helio=helio, flare_helio=flare_helio, ldata=ldata
    
;
;+
;   ssw_flare_locator
;
;   Purpose: locate flares from input data (3D or 2D)
;
;   Input Paramters:
;      index,data - ssw compliant 'index,data'; usually  
;                   one "before" and another during or shortly after peak
;   Output:
;      function returns xcen/ycen of flare 
;
;   Keyword Parameters:
;      limb_pad - size of above limb region to consider  ( -> solar_disk.pro )
;      smooth_width - width of box in boxcar smooth  
;      nosmooth - switch, if set, don't apply the smoothing algorithm
;      dark_flare - if set, look for dark, not bright "flare" (dimming?)
;      helio - if set, function return heliographic (arcmin2hel convention)
;      ldata - (output) - data array used in the location
;      flare_helio (output) - flare coordinates in heliographic
; 
;-
if n_elements(smooth_width) eq 0 then smooth_width=5
if keyword_set(nosmooth) then smooth_width=0
dark_flare=keyword_set(dark_flare)

case data_chk(data,/nimages) of 
   0: begin 
         box_message,"need at least one image..."
         return,-1
      endcase
   1: begin 
         box_message,'single not yet supported
      endcase
   2: begin
        box_message,'2 image case'
        difference_movie,index,data,oindex,odata
        ldata=bytscl(smooth(odata,smooth_width)) * $
             solar_mask(oindex,odata,pad=limb_pad)
        ss=where(ldata eq call_function((['max','min'])(dark_flare),ldata))
        xyp=coord_l2v(ss,size(ldata))
        oindex=struct2ssw(oindex)
        flrx=comp_fits_crval(oindex.xcen,oindex.cdelt1,oindex.naxis1,xyp(0))
        flry=comp_fits_crval(oindex.ycen,oindex.cdelt2,oindex.naxis2,xyp(1))
      endcase
   else: begin
      box_message,'more than 2 image case...
   endcase
endcase 

retval=-1
if n_elements(flrx) gt 0 then begin 
   retval=[flrx,flry]
   flare_helio=arcmin2hel(flrx/60.,flry/60.,$
          date=anytim(oindex.date_obs,/utc_int),$
          soho=strupcase(gt_tagval(oindex,/TELESCOP)) eq 'SOHO')
   if keyword_set(helio) then retval=flare_helio
endif

return,retval
end
